@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Type, Union, overload
+from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
@@ -77,7 +77,7 @@ __all__ = ("IoTAnalyticsClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -95,7 +95,7 @@ class Exceptions:
 
 class IoTAnalyticsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html)
     """
 
@@ -108,12 +108,12 @@ class IoTAnalyticsClient(BaseClient):
         """
 
     def batch_put_message(
-        self, *, channelName: str, messages: List["MessageTypeDef"]
+        self, *, channelName: str, messages: Sequence["MessageTypeDef"]
     ) -> BatchPutMessageResponseTypeDef:
         """
         Sends messages to a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.batch_put_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.batch_put_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#batch_put_message)
         """
 
@@ -121,7 +121,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#can_paginate)
         """
 
@@ -131,7 +131,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Cancels the reprocessing of data through the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.cancel_pipeline_reprocessing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.cancel_pipeline_reprocessing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#cancel_pipeline_reprocessing)
         """
 
@@ -141,12 +141,12 @@ class IoTAnalyticsClient(BaseClient):
         channelName: str,
         channelStorage: "ChannelStorageTypeDef" = None,
         retentionPeriod: "RetentionPeriodTypeDef" = None,
-        tags: List["TagTypeDef"] = None
+        tags: Sequence["TagTypeDef"] = None
     ) -> CreateChannelResponseTypeDef:
         """
         Used to create a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.create_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_channel)
         """
 
@@ -154,18 +154,18 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datasetName: str,
-        actions: List["DatasetActionTypeDef"],
-        triggers: List["DatasetTriggerTypeDef"] = None,
-        contentDeliveryRules: List["DatasetContentDeliveryRuleTypeDef"] = None,
+        actions: Sequence["DatasetActionTypeDef"],
+        triggers: Sequence["DatasetTriggerTypeDef"] = None,
+        contentDeliveryRules: Sequence["DatasetContentDeliveryRuleTypeDef"] = None,
         retentionPeriod: "RetentionPeriodTypeDef" = None,
         versioningConfiguration: "VersioningConfigurationTypeDef" = None,
-        tags: List["TagTypeDef"] = None,
-        lateDataRules: List["LateDataRuleTypeDef"] = None
+        tags: Sequence["TagTypeDef"] = None,
+        lateDataRules: Sequence["LateDataRuleTypeDef"] = None
     ) -> CreateDatasetResponseTypeDef:
         """
         Used to create a dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_dataset)
         """
 
@@ -176,7 +176,7 @@ class IoTAnalyticsClient(BaseClient):
         Creates the content of a dataset by applying a `queryAction` (a SQL query) or a
         `containerAction` (executing a containerized application).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_dataset_content)
         """
 
@@ -186,14 +186,14 @@ class IoTAnalyticsClient(BaseClient):
         datastoreName: str,
         datastoreStorage: "DatastoreStorageTypeDef" = None,
         retentionPeriod: "RetentionPeriodTypeDef" = None,
-        tags: List["TagTypeDef"] = None,
+        tags: Sequence["TagTypeDef"] = None,
         fileFormatConfiguration: "FileFormatConfigurationTypeDef" = None,
         datastorePartitions: "DatastorePartitionsTypeDef" = None
     ) -> CreateDatastoreResponseTypeDef:
         """
         Creates a data store, which is a repository for messages.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.create_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.create_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_datastore)
         """
 
@@ -201,13 +201,13 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         pipelineName: str,
-        pipelineActivities: List["PipelineActivityTypeDef"],
-        tags: List["TagTypeDef"] = None
+        pipelineActivities: Sequence["PipelineActivityTypeDef"],
+        tags: Sequence["TagTypeDef"] = None
     ) -> CreatePipelineResponseTypeDef:
         """
         Creates a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_pipeline)
         """
 
@@ -215,7 +215,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the specified channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_channel)
         """
 
@@ -223,7 +223,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the specified dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_dataset)
         """
 
@@ -231,7 +231,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the content of the specified dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_dataset_content)
         """
 
@@ -239,7 +239,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the specified data store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_datastore)
         """
 
@@ -247,7 +247,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_pipeline)
         """
 
@@ -257,7 +257,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves information about a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_channel)
         """
 
@@ -265,7 +265,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves information about a dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_dataset)
         """
 
@@ -275,7 +275,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves information about a data store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_datastore)
         """
 
@@ -283,7 +283,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves the current settings of the IoT Analytics logging options.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_logging_options)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_logging_options)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_logging_options)
         """
 
@@ -291,21 +291,21 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves information about a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_pipeline)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#generate_presigned_url)
         """
 
@@ -315,7 +315,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves the contents of a dataset as presigned URIs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.get_dataset_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.get_dataset_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#get_dataset_content)
         """
 
@@ -325,7 +325,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves a list of channels.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.list_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_channels)
         """
 
@@ -341,7 +341,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Lists information about dataset contents that have been created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.list_dataset_contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.list_dataset_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_dataset_contents)
         """
 
@@ -351,7 +351,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves information about datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_datasets)
         """
 
@@ -361,7 +361,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves a list of data stores.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datastores)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datastores)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_datastores)
         """
 
@@ -371,7 +371,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves a list of pipelines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_pipelines)
         """
 
@@ -379,7 +379,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Lists the tags (metadata) that you have assigned to the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_tags_for_resource)
         """
 
@@ -387,7 +387,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Sets or updates the IoT Analytics logging options.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.put_logging_options)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.put_logging_options)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#put_logging_options)
         """
 
@@ -395,12 +395,12 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         pipelineActivity: "PipelineActivityTypeDef",
-        payloads: List[Union[bytes, IO[bytes], StreamingBody]]
+        payloads: Sequence[Union[bytes, IO[bytes], StreamingBody]]
     ) -> RunPipelineActivityResponseTypeDef:
         """
         Simulates the results of running a pipeline activity on a message payload.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.run_pipeline_activity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.run_pipeline_activity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#run_pipeline_activity)
         """
 
@@ -416,7 +416,7 @@ class IoTAnalyticsClient(BaseClient):
         Retrieves a sample of messages from the specified channel ingested during the
         specified timeframe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.sample_channel_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.sample_channel_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#sample_channel_data)
         """
 
@@ -431,23 +431,23 @@ class IoTAnalyticsClient(BaseClient):
         """
         Starts the reprocessing of raw message data through the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.start_pipeline_reprocessing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.start_pipeline_reprocessing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#start_pipeline_reprocessing)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds to or modifies the tags of the given resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes the given tags (metadata) from the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#untag_resource)
         """
 
@@ -461,7 +461,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Used to update the settings of a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.update_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#update_channel)
         """
 
@@ -469,17 +469,17 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datasetName: str,
-        actions: List["DatasetActionTypeDef"],
-        triggers: List["DatasetTriggerTypeDef"] = None,
-        contentDeliveryRules: List["DatasetContentDeliveryRuleTypeDef"] = None,
+        actions: Sequence["DatasetActionTypeDef"],
+        triggers: Sequence["DatasetTriggerTypeDef"] = None,
+        contentDeliveryRules: Sequence["DatasetContentDeliveryRuleTypeDef"] = None,
         retentionPeriod: "RetentionPeriodTypeDef" = None,
         versioningConfiguration: "VersioningConfigurationTypeDef" = None,
-        lateDataRules: List["LateDataRuleTypeDef"] = None
+        lateDataRules: Sequence["LateDataRuleTypeDef"] = None
     ) -> None:
         """
         Updates the settings of a dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.update_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.update_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#update_dataset)
         """
 
@@ -494,24 +494,24 @@ class IoTAnalyticsClient(BaseClient):
         """
         Used to update the settings of a data store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.update_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.update_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#update_datastore)
         """
 
     def update_pipeline(
-        self, *, pipelineName: str, pipelineActivities: List["PipelineActivityTypeDef"]
+        self, *, pipelineName: str, pipelineActivities: Sequence["PipelineActivityTypeDef"]
     ) -> None:
         """
         Updates the settings of a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#update_pipeline)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listchannelspaginator)
         """
 
@@ -520,27 +520,27 @@ class IoTAnalyticsClient(BaseClient):
         self, operation_name: Literal["list_dataset_contents"]
     ) -> ListDatasetContentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listdatasetcontentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listdatasetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datastores"]) -> ListDatastoresPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listdatastorespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listpipelinespaginator)
         """
